<?php
/**
 * Zodiac Astrology Theme Customizer
 *
 * @package Zodiac Astrology
 */

get_template_part('/inc/select/category-dropdown-custom-control');

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function zodiacastrology_customize_register( $wp_customize ) {

	function zodiacastrology_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	}

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';


	// color site title
	$wp_customize->add_setting('zodiacastrology_sitetitle_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_sitetitle_color', array(
	   'settings' => 'zodiacastrology_sitetitle_color',
	   'section'   => 'title_tagline',
	   'label' => __('Site Title Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));


	$wp_customize->add_setting('zodiacastrology_title_enable',array(
		'default' => true,
		'sanitize_callback' => 'zodiacastrology_sanitize_checkbox',
	));
	$wp_customize->add_control( 'zodiacastrology_title_enable', array(
	   'settings' => 'zodiacastrology_title_enable',
	   'section'   => 'title_tagline',
	   'label'     => __('Enable Site Title','zodiac-astrology'),
	   'type'      => 'checkbox'
	));


	// color site tagline
	$wp_customize->add_setting('zodiacastrology_sitetagline_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_sitetagline_color', array(
	   'settings' => 'zodiacastrology_sitetagline_color',
	   'section'   => 'title_tagline',
	   'label' => __('Site Tagline Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));


	$wp_customize->add_setting('zodiacastrology_tagline_enable',array(
		'default' => true,
		'sanitize_callback' => 'zodiacastrology_sanitize_checkbox',
	));
	$wp_customize->add_control( 'zodiacastrology_tagline_enable', array(
	   'settings' => 'zodiacastrology_tagline_enable',
	   'section'   => 'title_tagline',
	   'label'     => __('Enable Site Tagline','zodiac-astrology'),
	   'type'      => 'checkbox'
	));

	//Theme Options
	$wp_customize->add_panel( 'zodiacastrology_panel_area', array(
		'priority' => 10,
		'capability' => 'edit_theme_options',
		'title' => __( 'Theme Options Panel', 'zodiac-astrology' ),
	) );
	
	// Header Section
	$wp_customize->add_section('zodiacastrology_header_section', array(
        'title' => __('Header Section', 'zodiac-astrology'),
        'priority' => null,
		'panel' => 'zodiacastrology_panel_area',
 	));


	$wp_customize->add_setting('zodiacastrology_fb_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'zodiacastrology_fb_link', array(
	   'settings' => 'zodiacastrology_fb_link',
	   'section'   => 'zodiacastrology_header_section',
	   'label' => __('Facebook Link', 'zodiac-astrology'),
	   'type'      => 'url'
	));

 
	// color facebook
	$wp_customize->add_setting('zodiacastrology_fb_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_fb_color', array(
	   'settings' => 'zodiacastrology_fb_color',
	   'section'   => 'zodiacastrology_header_section',
	   'label' => __('Facebook Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));


	$wp_customize->add_setting('zodiacastrology_twitt_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'zodiacastrology_twitt_link', array(
	   'settings' => 'zodiacastrology_twitt_link',
	   'section'   => 'zodiacastrology_header_section',
	   'label' => __('Twitter Link', 'zodiac-astrology'),
	   'type'      => 'url'
	));

	// color twitt
	$wp_customize->add_setting('zodiacastrology_twitt_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_twitt_color', array(
	   'settings' => 'zodiacastrology_twitt_color',
	   'section'   => 'zodiacastrology_header_section',
	   'label' => __('Twitter Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	$wp_customize->add_setting('zodiacastrology_linked_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'zodiacastrology_linked_link', array(
	   'settings' => 'zodiacastrology_linked_link',
	   'section'   => 'zodiacastrology_header_section',
	   'label' => __('Linkdin Link', 'zodiac-astrology'),
	   'type'      => 'url'
	));

	// color linked
	$wp_customize->add_setting('zodiacastrology_linked_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_linked_color', array(
	   'settings' => 'zodiacastrology_linked_color',
	   'section'   => 'zodiacastrology_header_section',
	   'label' => __('Linked Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	$wp_customize->add_setting('zodiacastrology_insta_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'zodiacastrology_insta_link', array(
	   'settings' => 'zodiacastrology_insta_link',
	   'section'   => 'zodiacastrology_header_section',
	   'label' => __('Instagram Link', 'zodiac-astrology'),
	   'type'      => 'url'
	));

	// color insta
	$wp_customize->add_setting('zodiacastrology_insta_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_insta_color', array(
	   'settings' => 'zodiacastrology_insta_color',
	   'section'   => 'zodiacastrology_header_section',
	   'label' => __('Instagram Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));


	// header menu
	$wp_customize->add_setting('zodiacastrology_menu_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_menu_color', array(
	   'settings' => 'zodiacastrology_menu_color',
	   'section'   => 'zodiacastrology_header_section',
	   'label' => __('Menu Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));


	// header menu hover color
	$wp_customize->add_setting('zodiacastrology_menuhrv_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_menuhrv_color', array(
	   'settings' => 'zodiacastrology_menuhrv_color',
	   'section'   => 'zodiacastrology_header_section',
	   'label' => __('Menu Hover Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	// header sub menu color
	$wp_customize->add_setting('zodiacastrology_submenu_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_submenu_color', array(
	   'settings' => 'zodiacastrology_submenu_color',
	   'section'   => 'zodiacastrology_header_section',
	   'label' => __('SubMenu Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	// header sub menu bg color
	$wp_customize->add_setting('zodiacastrology_submenubg_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_submenubg_color', array(
	   'settings' => 'zodiacastrology_submenubg_color',
	   'section'   => 'zodiacastrology_header_section',
	   'label' => __('SubMenu BG Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	// header sub menu hover color
	$wp_customize->add_setting('zodiacastrology_submenuhrv_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_submenuhrv_color', array(
	   'settings' => 'zodiacastrology_submenuhrv_color',
	   'section'   => 'zodiacastrology_header_section',
	   'label' => __('SubMenu Hover Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	// header sub menu bg hover color
	$wp_customize->add_setting('zodiacastrology_submenubghrv_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_submenubghrv_color', array(
	   'settings' => 'zodiacastrology_submenubghrv_color',
	   'section'   => 'zodiacastrology_header_section',
	   'label' => __('SubMenu BG Hover Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));


	// Home Category Dropdown Section
	$wp_customize->add_section('zodiacastrology_one_cols_section',array(
		'title'	=> __('Slider','zodiac-astrology'),
		'description'	=> __('Select Category from the Dropdowns for slider, Also use the given image dimension (1600 x 850).','zodiac-astrology'),
		'priority'	=> null,
		'panel' => 'zodiacastrology_panel_area'
	));

	// Add a category dropdown Slider Coloumn
	$wp_customize->add_setting( 'zodiacastrology_slidersection', array(
		'default'	=> '0',	
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new zodiacastrology_Category_Dropdown_Custom_Control( $wp_customize, 'zodiacastrology_slidersection', array(
		'section' => 'zodiacastrology_one_cols_section',
		'settings'   => 'zodiacastrology_slidersection',
	) ) );

	//Hide Section
	$wp_customize->add_setting('zodiacastrology_hide_categorysec',array(
		'default' => false,
		'sanitize_callback' => 'zodiacastrology_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 

	$wp_customize->add_control( 'zodiacastrology_hide_categorysec', array(
	   'settings' => 'zodiacastrology_hide_categorysec',
	   'section'   => 'zodiacastrology_one_cols_section',
	   'label'     => __('Check To Enable This Section','zodiac-astrology'),
	   'type'      => 'checkbox'
	));

	$wp_customize->add_setting('zodiacastrology_button_text',array(
		'default' => 'Read More',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'zodiacastrology_button_text', array(
	   'settings' => 'zodiacastrology_button_text',
	   'section'   => 'zodiacastrology_one_cols_section',
	   'label' => __('Add Button Text', 'zodiac-astrology'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('zodiacastrology_button2_text',array(
		'default' => 'Contact Us',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'zodiacastrology_button2_text', array(
	   'settings' => 'zodiacastrology_button2_text',
	   'section'   => 'zodiacastrology_one_cols_section',
	   'label' => __('Add Button 2 Text', 'zodiac-astrology'),
	   'type'      => 'text'
	));


	// color slider title
	$wp_customize->add_setting('zodiacastrology_slidertitle_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_slidertitle_color', array(
	   'settings' => 'zodiacastrology_slidertitle_color',
	   'section'   => 'zodiacastrology_one_cols_section',
	   'label' => __('Title Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	// color slider description
	$wp_customize->add_setting('zodiacastrology_sliderdescription_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_sliderdescription_color', array(
	   'settings' => 'zodiacastrology_sliderdescription_color',
	   'section'   => 'zodiacastrology_one_cols_section',
	   'label' => __('Description Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));


	// color slider button1 text
	$wp_customize->add_setting('zodiacastrology_sliderbutton1text_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_sliderbutton1text_color', array(
	   'settings' => 'zodiacastrology_sliderbutton1text_color',
	   'section'   => 'zodiacastrology_one_cols_section',
	   'label' => __('Button 1 Text Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	// color slider button1 
	$wp_customize->add_setting('zodiacastrology_sliderbutton1_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_sliderbutton1_color', array(
	   'settings' => 'zodiacastrology_sliderbutton1_color',
	   'section'   => 'zodiacastrology_one_cols_section',
	   'label' => __('Button 1 Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	// color slider button2 text
	$wp_customize->add_setting('zodiacastrology_sliderbutton2text_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_sliderbutton2text_color', array(
	   'settings' => 'zodiacastrology_sliderbutton2text_color',
	   'section'   => 'zodiacastrology_one_cols_section',
	   'label' => __('Button 2 Text Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	// color slider button2 
	$wp_customize->add_setting('zodiacastrology_sliderbutton2_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_sliderbutton2_color', array(
	   'settings' => 'zodiacastrology_sliderbutton2_color',
	   'section'   => 'zodiacastrology_one_cols_section',
	   'label' => __('Button 2 Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));



	
	// Services Section 
	$wp_customize->add_section('zodiacastrology_below_slider_section', array(
		'title'	=> __('Services Section','zodiac-astrology'),
		'description'	=> __('Select Pages from the dropdown for Services.','zodiac-astrology'),
		'priority'	=> null,
		'panel' => 'zodiacastrology_panel_area',
	));

	
	// Add a category dropdown Slider Coloumn
	$wp_customize->add_setting( 'zodiacastrology_services_cat', array(
		'default'	=> '0',	
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new zodiacastrology_Category_Dropdown_Custom_Control( $wp_customize, 'zodiacastrology_services_cat', array(
		'section' => 'zodiacastrology_below_slider_section',
		'settings'   => 'zodiacastrology_services_cat',
	) ) );

	$wp_customize->add_setting('zodiacastrology_disabled_pgboxes',array(
		'default' => false,
		'sanitize_callback' => 'zodiacastrology_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));
	
	$wp_customize->add_control( 'zodiacastrology_disabled_pgboxes', array(
	   'settings' => 'zodiacastrology_disabled_pgboxes',
	   'section'   => 'zodiacastrology_below_slider_section',
	   'label'     => __('Check To Enable This Section','zodiac-astrology'),
	   'type'      => 'checkbox'
	));


	$wp_customize->add_setting('zodiacastrology_service_heading',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'zodiacastrology_service_heading', array(
	   'settings' => 'zodiacastrology_service_heading',
	   'section'   => 'zodiacastrology_below_slider_section',
	   'label' => __('Heading', 'zodiac-astrology'),
	   'type'      => 'text'
	));

	//  service heading color 
	$wp_customize->add_setting('zodiacastrology_serviceheading_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_serviceheading_color', array(
	   'settings' => 'zodiacastrology_serviceheading_color',
	   'section'   => 'zodiacastrology_below_slider_section',
	   'label' => __('Heading Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));
 

	$wp_customize->add_setting('zodiacastrology_service_subheading',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'zodiacastrology_service_subheading', array(
	   'settings' => 'zodiacastrology_service_subheading',
	   'section'   => 'zodiacastrology_below_slider_section',
	   'label' => __('Sub Heading', 'zodiac-astrology'),
	   'type'      => 'text'
	));

	//  service subheading color 
	$wp_customize->add_setting('zodiacastrology_servicesubheading_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_servicesubheading_color', array(
	   'settings' => 'zodiacastrology_servicesubheading_color',
	   'section'   => 'zodiacastrology_below_slider_section',
	   'label' => __('SubHeading Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));


	//  service title color 
	$wp_customize->add_setting('zodiacastrology_servicetitle_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_servicetitle_color', array(
	   'settings' => 'zodiacastrology_servicetitle_color',
	   'section'   => 'zodiacastrology_below_slider_section',
	   'label' => __('Title Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	//  service description color 
	$wp_customize->add_setting('zodiacastrology_servicedescription_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_servicedescription_color', array(
	   'settings' => 'zodiacastrology_servicedescription_color',
	   'section'   => 'zodiacastrology_below_slider_section',
	   'label' => __('Description Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));
	


	// blog Section 
	$wp_customize->add_section('zodiacastrology_below_blog_section', array(
		'title'	=> __('Blog Section','zodiac-astrology'),
		'description'	=> __('Select Pages from the dropdown for blog.','zodiac-astrology'),
		'priority'	=> null,
		'panel' => 'zodiacastrology_panel_area',
	));

	
	// Add a category dropdown Slider Coloumn
	$wp_customize->add_setting( 'zodiacastrology_blog_cat', array(
		'default'	=> '0',	
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new zodiacastrology_Category_Dropdown_Custom_Control( $wp_customize, 'zodiacastrology_blog_cat', array(
		'section' => 'zodiacastrology_below_blog_section',
		'settings'   => 'zodiacastrology_blog_cat',
	) ) );

	$wp_customize->add_setting('zodiacastrology_disabled_blogpgboxes',array(
		'default' => false,
		'sanitize_callback' => 'zodiacastrology_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));
	
	$wp_customize->add_control( 'zodiacastrology_disabled_blogpgboxes', array(
	   'settings' => 'zodiacastrology_disabled_blogpgboxes',
	   'section'   => 'zodiacastrology_below_blog_section',
	   'label'     => __('Check To Enable This Section','zodiac-astrology'),
	   'type'      => 'checkbox'
	));


	$wp_customize->add_setting('zodiacastrology_blog_heading',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'zodiacastrology_blog_heading', array(
	   'settings' => 'zodiacastrology_blog_heading',
	   'section'   => 'zodiacastrology_below_blog_section',
	   'label' => __('Heading', 'zodiac-astrology'),
	   'type'      => 'text'
	));

	//  blog heading color 
	$wp_customize->add_setting('zodiacastrology_blogheading_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_blogheading_color', array(
	   'settings' => 'zodiacastrology_blogheading_color',
	   'section'   => 'zodiacastrology_below_blog_section',
	   'label' => __('Heading Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

 

	$wp_customize->add_setting('zodiacastrology_blog_subheading',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'zodiacastrology_blog_subheading', array(
	   'settings' => 'zodiacastrology_blog_subheading',
	   'section'   => 'zodiacastrology_below_blog_section',
	   'label' => __('Sub Heading', 'zodiac-astrology'),
	   'type'      => 'text'
	));


	//  blog subheading color 
	$wp_customize->add_setting('zodiacastrology_blogsubheading_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_blogsubheading_color', array(
	   'settings' => 'zodiacastrology_blogsubheading_color',
	   'section'   => 'zodiacastrology_below_blog_section',
	   'label' => __('SubHeading Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	//  blog title color 
	$wp_customize->add_setting('zodiacastrology_blogtitle_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_blogtitle_color', array(
	   'settings' => 'zodiacastrology_blogtitle_color',
	   'section'   => 'zodiacastrology_below_blog_section',
	   'label' => __('Title Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	//  blog description color 
	$wp_customize->add_setting('zodiacastrology_blogdescription_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_blogdescription_color', array(
	   'settings' => 'zodiacastrology_blogdescription_color',
	   'section'   => 'zodiacastrology_below_blog_section',
	   'label' => __('Description Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	// blog button color 
	$wp_customize->add_setting('zodiacastrology_blogbutton_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_blogbutton_color', array(
	   'settings' => 'zodiacastrology_blogbutton_color',
	   'section'   => 'zodiacastrology_below_blog_section',
	   'label' => __('Button Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	// blog datecomm color 
	$wp_customize->add_setting('zodiacastrology_blogdatecomm_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control('zodiacastrology_blogdatecomm_color', array(
	   'settings' => 'zodiacastrology_blogdatecomm_color',
	   'section'   => 'zodiacastrology_below_blog_section',
	   'label' => __('Date & comment Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	// blog datecommicon color 
	$wp_customize->add_setting('zodiacastrology_blogdatecommicon_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_blogdatecommicon_color', array(
	   'settings' => 'zodiacastrology_blogdatecommicon_color',
	   'section'   => 'zodiacastrology_below_blog_section',
	   'label' => __('Date Icon Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));



 
	// Footer Section 
	$wp_customize->add_section('zodiacastrology_footer', array(
		'title'	=> __('Footer Section','zodiac-astrology'),
		'priority'	=> null,
		'panel' => 'zodiacastrology_panel_area',
	));

	$wp_customize->add_setting('zodiacastrology_copyright_line',array(
		'sanitize_callback' => 'sanitize_text_field',
	));	
	$wp_customize->add_control( 'zodiacastrology_copyright_line', array(
	   'section' 	=> 'zodiacastrology_footer',
	   'label'	 	=> __('Copyright Line','zodiac-astrology'),
	   'type'    	=> 'text',
	   'priority' 	=> null,
    ));


	//  footer coypright color 
	$wp_customize->add_setting('zodiacastrology_footercoypright_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_footercoypright_color', array(
	   'settings' => 'zodiacastrology_footercoypright_color',
	   'section'   => 'zodiacastrology_footer',
	   'label' => __('Coypright Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	//  footer coyprighthrv color 
	$wp_customize->add_setting('zodiacastrology_footercoyprighthrv_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_footercoyprighthrv_color', array(
	   'settings' => 'zodiacastrology_footercoyprighthrv_color',
	   'section'   => 'zodiacastrology_footer',
	   'label' => __('Coypright Hover Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));



	//  footer bg color 
	$wp_customize->add_setting('zodiacastrology_footerbg_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_footerbg_color', array(
	   'settings' => 'zodiacastrology_footerbg_color',
	   'section'   => 'zodiacastrology_footer',
	   'label' => __('BG Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));


	//  footer title color 
	$wp_customize->add_setting('zodiacastrology_footertitle_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_footertitle_color', array(
	   'settings' => 'zodiacastrology_footertitle_color',
	   'section'   => 'zodiacastrology_footer',
	   'label' => __('Title Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	//  footer description color 
	$wp_customize->add_setting('zodiacastrology_footerdescription_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_footerdescription_color', array(
	   'settings' => 'zodiacastrology_footerdescription_color',
	   'section'   => 'zodiacastrology_footer',
	   'label' => __('Description Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));

	//  footer list color 
	$wp_customize->add_setting('zodiacastrology_footerlist_color',array(
		'default' => '',
		'sanitize_callback' => 'zodiacastrology_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'zodiacastrology_footerlist_color', array(
	   'settings' => 'zodiacastrology_footerlist_color',
	   'section'   => 'zodiacastrology_footer',
	   'label' => __('List Color', 'zodiac-astrology'),
	   'type'      => 'color'
	));


}
add_action( 'customize_register', 'zodiacastrology_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function zodiacastrology_customize_preview_js() {
	wp_enqueue_script( 'zodiacastrology_customizer', esc_url(get_template_directory_uri()) . '/js/customize-preview.js', array( 'customize-preview' ), '20161510', true );
}
add_action( 'customize_preview_init', 'zodiacastrology_customize_preview_js' );